"""
hypixel.models
~~~~~~~~~~~~~~~~~~~

A module for modeling data.

(c) 2021-present duhby
MIT License, see LICENSE for more details.
"""

from .bans import Bans
from .color import ColorType
from .friend import Friend
from .games import Game, GameCount, GameCounts, GameType
from .guild import Guild, GuildMember, GuildRank
from .key import Key
from .player import Player
from .status import Status
